@@ -2,7 +2,9 @@
 This module implements the logic for the `/transactions/deposit` endpoints.
 This lets a user initiate a deposit of an asset into their Stellar account.
 """
+from decimal import Decimal, DecimalException
 from urllib.parse import urlencode
+from polaris.utils import getLogger
 
 from django.urls import reverse
 from django.shortcuts import redirect
@@ -21,7 +23,6 @@ from polaris import settings
 from polaris.templates import Template
 from polaris.utils import (
     render_error_response,
-    Logger,
     extract_sep9_fields,
     create_transaction_id,
     memo_str,
@@ -45,7 +46,7 @@ from polaris.integrations import (
     calculate_fee,
 )
 
-logger = Logger(__name__)
+logger = getLogger(__name__)
 
 
 @xframe_options_exempt
@@ -84,9 +85,6 @@ def post_interactive_deposit(request: Request) -> Response:
     amount = args_or_error["amount"]
 
     form = rdi.form_for_transaction(transaction, post_data=request.POST)
-    content = rdi.content_for_template(
-        Template.DEPOSIT, form=form, transaction=transaction
-    )
     if not form:
         logger.error(
             "Initial form_for_transaction() call returned None in "
@@ -145,6 +143,12 @@ def post_interactive_deposit(request: Request) -> Response:
             return redirect(f"{url}?{args}")
 
     else:
+        content = (
+            rdi.content_for_template(
+                Template.DEPOSIT, form=form, transaction=transaction
+            )
+            or {}
+        )
         scripts = registered_scripts_func({"form": form, **content})
 
         url_args = {"transaction_id": transaction.id, "asset_code": asset.code}
@@ -156,6 +160,7 @@ def post_interactive_deposit(request: Request) -> Response:
         post_url = f"{reverse('post_interactive_deposit')}?{urlencode(url_args)}"
         get_url = f"{reverse('get_interactive_deposit')}?{urlencode(url_args)}"
         content.update(
+            form=form,
             post_url=post_url,
             get_url=get_url,
             scripts=scripts,
@@ -311,6 +316,13 @@ def deposit(account: str, request: Request) -> Response:
     except ValueError:
         return render_error_response(_("invalid 'memo' for 'memo_type'"))
 
+    amount = None
+    if request.POST.get("amount"):
+        try:
+            amount = Decimal(request.POST.get("amount"))
+        except DecimalException as e:
+            return render_error_response(_("Invalid 'amount'"))
+
     # Verify that the asset code exists in our database, with deposit enabled.
     asset = Asset.objects.filter(code=asset_code).first()
     if not asset:
@@ -347,7 +359,12 @@ def deposit(account: str, request: Request) -> Response:
     logger.info(f"Created deposit transaction {transaction_id}")
 
     url = interactive_url(
-        request, str(transaction_id), account, asset_code, settings.OPERATION_DEPOSIT,
+        request,
+        str(transaction_id),
+        account,
+        asset_code,
+        settings.OPERATION_DEPOSIT,
+        amount,
     )
     return Response(
         {"type": "interactive_customer_info_needed", "url": url, "id": transaction_id},
